// Package router ...
//
// Description : router ...
//
// Author : go_developer@163.com<白茶清欢>
//
// Date : 2024-07-20 22:57
package router

import "reflect"

const (
	PrefixFuncName     = "RouterPrefix"     // 路由前缀函数名称
	MiddlewareFuncName = "RouterMiddleware" // 路由中间件函数名称
)

const (
	TagNamePath   = "path"   // 接口的请求路径
	TagNameMethod = "method" // 接口的请求方法
	TagNameUriTag = "tag"    // 接口的tag
	TagNameDesc   = "desc"   // 接口的描述
	TagNameStrict = "strict" // 接口是否为严格模式 : 不配置, 则为严格模式.严格模式 : POST 仅解析 BODY , GET 仅解析 QUERY
)

// UriConfig 接口配置
//
// Author : go_developer@163.com<白茶清欢>
//
// Date : 15:41 2024/7/21
type UriConfig struct {
	Path         string              `json:"path"`        // 接口路由, 必须配置
	Method       string              `json:"method"`      // 接口请求方法, 必须配置
	TagList      []string            `json:"tag_list"`    // 接口分组
	Desc         string              `json:"desc"`        // 接口描述
	Strict       bool                `json:"strict"`      // 接口是否为严格模式 : 不配置, 则为严格模式.严格模式 : POST 仅解析 BODY , GET 仅解析 QUERY
	ParamTable   map[string]UriParam `json:"param_table"` // 参数信息表
	FormDataType reflect.Type        `json:"-"`           // 表单数据类型
}

// UriParam 接口参数配置
//
// Author : go_developer@163.com<白茶清欢>
//
// Date : 15:40 2025/1/27
type UriParam struct {
	Name            string `json:"name"`              // 参数名称
	Type            string `json:"type"`              // 参数类型
	DisableAutoType bool   `json:"disable_auto_type"` // 禁用自动类型转换
	Sort            string `json:"sort"`              // 参数读取顺序: 默认 POST : body > query > path GET : query > path > body
}

const (
	FieldNameMeta = "Meta" // 元信息字段
)
